@@ -8,7 +8,7 @@ import click
 from .app_manager import start_app
 from .graphql import graphql
 from .run import run
-from .sql_alembic import db
+from .sql_alembic import db, ALEMBIC_CONFIG
 
 
 @click.group()
@@ -20,4 +20,6 @@ def cli():
 cli.add_command(run)
 cli.add_command(graphql)
 cli.add_command(start_app)
-cli.add_command(db)
+
+if ALEMBIC_CONFIG:
+    cli.add_command(db)
